@@ -366,7 +366,7 @@ sub get_management_config {
     templates=>$templates,
   };
 
-  $config->{replace}=JSON::false;
+  $config->{replace}=&JSON::false;
   return $self->RESULT_CLASS->new_true($config);
 }
 
@@ -555,7 +555,6 @@ sub add_volumes {
   my $vol_map=$result->get_data->{'map'};
   my $MaxVolumeIndex=$result->get_data->{MaxVolumeIndex};
 
-
   my $added={};
   PROV_LOOP: foreach my $vol (@vols) {
     my $path=$vol->{path};
@@ -566,18 +565,26 @@ sub add_volumes {
     } else {
       ++$MaxVolumeIndex;
       $self->log_warn("volume does not exist we will create: $path");
+      #%{ $map->{$vol->{type}}},
+      my $type=$vol->{type};
+      my %type_options;
+      # perhaps the snmp lookup can fail?
+      %type_options=%{ $map->{$type} } if exists $map->{$type};
+
       my %args=(
         Caption=>$path,
         VolumeDescription=>$path,
-        %{$map->{$vol->{type}}},
         NodeID=>$node_id,
 	VolumeIndex=>$MaxVolumeIndex,
+	%type_options
       );
+
       $result=$self->add_volume(%args);
       unless($result) {
         $self->log_warn("failed to add volume $path error was: $result");
         next PROV_LOOP;
       }
+
       my $url=$result->get_data;
       $url=~ s/(?:^"|"$)//g;
       my ($VolumeID)=$url=~ /(\d+)$/;
